@@ -29,64 +29,66 @@ DEFAULT_CONFIG = """{
         "tongue": "en",
         "confirm": false,
         "basename": false,
-        "treeview": true
+        "treeview": true,
+        'tabasspaces' : true
     },
     "messages": {
         "en" : {
-            "started"    : "Started",
-            "about_msg"  : "Made with ❤",
-            "unsaved"    : "Unsaved changes",
-            "unsaved_msg": "There are unsaved changes.\\nDo you really want to quit Jyx?",
-            "open file"  : "Open file...",
-            "save file"  : "Save file...",
-            "filter all" : "all files",
-            "file name"  : "myfile"
+            "started"     : "Started",
+            "about_msg"   : "Made with ❤",
+            "unsaved"     : "Unsaved changes",
+            "unsaved_msg" : "There are unsaved changes.\\nDo you really want to quit Jyx?",
+            "open file"   : "Open file...",
+            "save file"   : "Save file...",
+            "filter all"  : "all files",
+            "file name"   : "myfile"
         }
     },
     "menu": {
         "en": {
-            "tongue"     : "English",
-            "file"       : "File",
-            "new"        : "New",
-            "open"       : "Open...",
-            "save"       : "Save",
-            "save as"    : "Save As...",
-            "save all"   : "Save All",
-            "run"        : "Run Script",
-            "close tab"  : "Close Tab",
-            "exit"       : "Exit",
-            "edit"       : "Edit",
-            "undo"       : "Undo",
-            "redo"       : "Redo",
-            "cut"        : "Cut",
-            "copy"       : "Copy",
-            "paste"      : "Paste",
-            "select all" : "Select all",
-            "clear"      : "Clear",
-            "options"    : "Options",
-            "tongues"    : "Tongues",
-            "confirm"    : "Confirm before exit",
-            "basename"   : "Display only the name",
-            "treeview"   : "Display tree",
-            "languages"  : "Languages",
-            "help"       : "Help",
-            "about"      : "About..."
+            "tongue"      : "English",
+            "file"        :  "File",
+            "new"         : "New",
+            "open"        : "Open...",
+            "save"        : "Save",
+            "save as"     : "Save As...",
+            "save all"    : "Save All",
+            "run"         : "Run Script",
+            "close tab"   : "Close Tab",
+            "exit"        : "Exit",
+            "edit"        : "Edit",
+            "undo"        : "Undo",
+            "redo"        : "Redo",
+            "cut"         : "Cut",
+            "copy"        : "Copy",
+            "paste"       : "Paste",
+            "select all"  : "Select all",
+            "clear"       : "Clear",
+            "options"     : "Options",
+            "tongues"     : "Tongues",
+            "confirm"     : "Confirm before exit",
+            "basename"    : "Display only the name",
+            "treeview"    : "Display tree",
+            "tabasspaces" : "Tab as spaces",
+            "languages"   : "Languages",
+            "help"        : "Help",
+            "about"       : "About..."
         }
     },
     "languages" : {
         "text" : {
-            "label": "Plain text",
-            "extension": [".txt"],
-            "family": "",
-            "support": "",
-            "token": [],
-            "style": {
-                "default": {
+            "label"       : "Plain text",
+            "extension"   : [".txt"],
+            "family"      : "",
+            "support"     : "",
+            "token"       : [],
+            "style"       : {
+                "default" : {
                 }
             }
         }
     },
-    "default_language" : "text"
+    "default_language"    : "text"
 }
 """
 
@@ -156,7 +158,7 @@ class Jyx:
     CLOSE_TAB = 8
     DATA_FILE_NAME = 'jyx.json'
     LAST_VALUES = 'last_values.json'
-    VERSION = '0.0.2'
+    VERSION = '0.0.3'
     
     def __init__(self):
         self.log = Logger(exit_on_error=False, info=Output.CONSOLE, 
@@ -261,7 +263,7 @@ class Jyx:
         self.root.wm_title(f"{Jyx.TITLE} {Jyx.VERSION} - {i}/{nb} {file}{dirty}")
 
     def update_status(self, event=None):
-        self.menu.status_bar.configure(text=self.notebook.current().lang + ' - ' + self.notebook.get_position())
+        self.notebook.current().status_bar.configure(text=self.notebook.current().lang + ' - ' + self.notebook.get_position())
 
     def update_all_options(self):
         for key in self.options:
@@ -301,6 +303,8 @@ class Jyx:
             elif not val:
                 self.treeview.place_forget()
                 self.notebook.place(relx=0.0, rely =0.0, relwidth =1.0, relheight =1.0)
+        elif varname == 'tabasspace':
+            pass
         opt.prev = val
 
     def has(self, prop, value, content=None):
@@ -496,10 +500,12 @@ class JyxMenu(tk.Menu):
         self.options_menu.entryconfig(data['menu'][old]['tongues'], label=data['menu'][new]['tongues'])
         self.options_menu.entryconfig(data['menu'][old]['confirm'], label=data['menu'][new]['confirm'])
         self.options_menu.entryconfig(data['menu'][old]['basename'], label=data['menu'][new]['basename'])
+        self.options_menu.entryconfig(data['menu'][old]['treeview'], label=data['menu'][new]['treeview'])
+        self.options_menu.entryconfig(data['menu'][old]['tabasspaces'], label=data['menu'][new]['tabasspaces'])
         
         self.help_menu.entryconfig(data['menu'][old]['about'], label=data['menu'][new]['about'])
 
-        self.status_bar.config(text=data['messages'][new]['started'])
+        #self.jyx.notebook.current().status_bar.config(text=data['messages'][new]['started'])
 
     def build(self):
         data = self.jyx.data
@@ -582,7 +588,11 @@ class JyxMenu(tk.Menu):
                                           onvalue=True, offvalue=False,
                                           variable=self.jyx.options['treeview'].var,
                                           command=lambda: self.jyx.update('treeview'))
-        
+        self.options_menu.add_checkbutton(label=data['menu'][tongue]['tabasspaces'],
+                                          onvalue=True, offvalue=False,
+                                          variable=self.jyx.options['tabasspaces'].var,
+                                          command=lambda: self.jyx.update('tabasspaces'))
+
         self.langmenu = tk.Menu(self, tearoff=0)
         self.add_cascade(label=data['menu'][tongue]['languages'], menu=self.langmenu)
 
@@ -615,11 +625,6 @@ class JyxMenu(tk.Menu):
         self.add_cascade(label=data['menu'][tongue]['help'], menu=self.help_menu)
         self.help_menu.add_command(label=data['menu'][tongue]['about'], command=self.jyx.about)
 
-        # Status bas
-        self.status_bar = tk.Label(self.jyx.get_root(), bd=1, relief=tk.SUNKEN)
-        self.status_bar.config(text=data['messages'][tongue]['started'], anchor=tk.E, padx=20)
-        self.status_bar.pack(side=tk.BOTTOM, fill=tk.X)
-
 
 class JyxTree(ttk.Treeview):
 
@@ -682,15 +687,9 @@ class JyxNotebook(ttk.Notebook):
     def __init__(self, jyx):
         ttk.Notebook.__init__(self, jyx.get_root())
         self.jyx = jyx
-
-        # To make the element at 0,0 grows with the window
-        self.grid_rowconfigure(0, weight=1)
-        self.grid_columnconfigure(0, weight=1)
-
         self.notes = []
         self.is_loading_file = True # for the first time, to desactivate jyx#update
         self.new_tab()
-        self.pack(fill=tk.BOTH, expand=tk.YES)
         self.bind('<<NotebookTabChanged>>', self.on_tab_change)
         self.current().focus()
         self.is_loading_file = False
@@ -804,18 +803,12 @@ class JyxNote:
         self.notebook = notebook
 
         self.frame = ttk.Frame(self.notebook) #, bd=2, relief=tk.SUNKEN)
-        self.frame.grid_rowconfigure(0, weight=1)
-        self.frame.grid_columnconfigure(0, weight=1)
-        
         self.scrollbar = ttk.Scrollbar(self.frame)
-        self.scrollbar.grid(row=0, column=1, sticky=tk.N+tk.S)
-
         self.text = tk.Text(self.frame, wrap=tk.NONE, bd=0, undo=True,
                             yscrollcommand=self.scrollbar.set)
         self.scrollbar.configure(command=self.text.yview)
         
         self.text.config(font=('consolas', 12), undo=True, wrap='word')
-        self.text.grid(row=0, column=0, sticky=tk.N+tk.S+tk.E+tk.W)
         self.text.bind('<KeyPress>', self.update_text_before)
         #self.text.bind('<KeyRelease>', self.update_text_after)
         self.text.bind('<ButtonRelease-1>', self.notebook.jyx.update_status)
@@ -830,11 +823,27 @@ class JyxNote:
             self.text.bind('<Control-Key-v>', self.paste)
             self.text.bind('<Control-Key-p>', self.notebook.jyx.treeview.rebuild)
             self.text.bind('<Control-Key-s>', self.notebook.jyx.save)
-    
+
+        # Status bas
+        jyx = self.notebook.jyx
+        self.status_bar = tk.Label(self.frame, bd=1, relief=tk.SUNKEN)
+        #jyx.data['messages'][jyx.options['tongue'].get()]['started'] text will be updated ASAP
+        self.status_bar.config(text='', anchor=tk.E, padx=20)
+
+        # Attributes
         self.filepath = None
         self.dirty = False
         self.lang = lang
 
+        # Layout
+        self.frame.grid_rowconfigure(0, weight=100)
+        self.frame.grid_rowconfigure(1, weight=1)
+        self.frame.grid_columnconfigure(0, weight=1)
+
+        self.text.grid(row=0, column=0, sticky=tk.NS+tk.EW)
+        self.scrollbar.grid(row=0, column=1, sticky=tk.NS)
+        self.status_bar.grid(row=2, column=0, columnspan=2, sticky=tk.EW)
+        
         # Tags
         self.tokens = {}
         self.tags = {}
@@ -1059,8 +1068,17 @@ class JyxNote:
             if len(text.tag_ranges('sel')) > 0:
                 self.selection_delete()
             else:
-                text.mark_set(tk.INSERT, 'insert-1c')
-                self.delete(tk.INSERT)
+                if self.notebook.jyx.options['tabasspaces'].get():
+                    col = int(self.text.index("insert").split('.')[1]);
+                    nb = col % 4
+                    nb = 4 if nb == 0 else nb
+                    if self.text.get('insert-%dc' % (nb,), tk.INSERT).isspace():
+                        self.delete('insert-%dc' % (nb,), tk.INSERT)
+                    else:
+                        self.delete('insert-1c', tk.INSERT)
+                    #text.mark_set(tk.INSERT, 'insert-%dc' % (nb,))
+                else:
+                    self.delete('insert-1c', tk.INSERT)
             self.notebook.jyx.update_status()
             return 'break'
         elif event.keysym == 'Delete':
@@ -1075,16 +1093,23 @@ class JyxNote:
             self.notebook.jyx.update_status()
             return 'break'
         elif event.keysym == 'Return':
-            line = self.text.get('insert linestart', 'insert lineend')
-            decal = len(line) - len(line.lstrip())
-            if decal > 0:
-                content = '\n' + ' ' * decal
+            if self.notebook.jyx.options['tabasspaces'].get():
+                line = self.text.get('insert linestart', 'insert lineend')
+                decal = len(line) - len(line.lstrip())
+                if decal > 0:
+                    content = '\n' + ' ' * decal
+                else:
+                    content = '\n'
             else:
                 content = '\n'
         elif event.char == '\r':
             content = '\n'
         elif event.char == '\t':
-            content = '    '
+            if self.notebook.jyx.options['tabasspaces'].get():
+                col = int(self.text.index("insert").split('.')[1]);
+                content = ' ' * (4 - (col % 4))
+            else:
+                content = '\t'
         elif event.keysym == 'space':
             content = ' '
         elif event.char.isprintable(): #isalnum()
